package com.usky.oa;
import io.swagger.annotations.SwaggerDefinition;
import org.mybatis.spring.annotation.MapperScan;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.rabbit.annotation.EnableRabbit;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.openfeign.EnableFeignClients;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.core.env.Environment;
import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 * 系统模块
 * 
 * @author ruoyi
 */

//@EnableSwagger2
@EnableFeignClients(basePackages = "com.usky")
@MapperScan(value = "com.usky.oa.mapper")
@ComponentScan("com.usky")
@SpringBootApplication
@EnableRabbit
public class ServiceOaApplication
{
    private static final Logger LOGGER = LoggerFactory.getLogger(ServiceOaApplication.class);

    public static void main(String[] args) throws UnknownHostException {
        ConfigurableApplicationContext application = SpringApplication.run(ServiceOaApplication.class, args);
        Environment env = application.getEnvironment();
        String ip = InetAddress.getLocalHost().getHostAddress();
        String port = env.getProperty("server.port");
        String path = env.getProperty("server.servlet.context-path");
        LOGGER.info("\n----------------------------------------------------------\n\t" +
                "Application is running! Access URLs:\n\t" +
                "Local: \t\thttp://localhost:" + port + (null==path?"":path) + "/\n\t" +
                "External: \thttp://" + ip + ":" + port + (null==path?"":path) + "/\n\t" +
                "Api: \t\thttp://" + ip + ":" + port + (null==path?"":path) + "/swagger-ui/index.html\n\t" +
                "----------------------------------------------------------");
    }
}
